@@ -10,7 +10,7 @@ our @EXPORT_OK = qw(
                        declare_property
                );
 
-our $VERSION = '0.02'; # VERSION
+our $VERSION = '0.03'; # VERSION
 
 sub declare_property {
     my %args   = @_;
@@ -54,20 +54,34 @@ sub declare_property {
         ($bpp // $tpp)->{$name} = $schema;
     }
 
-    # install wrapper
-    {
-        require Perinci::Sub::Wrapper;
+    # install wrapper handler
+    if ($args{wrapper} && $INC{"Perinci/Sub/Wrapper.pm"}) {
         no strict 'refs';
         my $n = $name; $n =~ s!/!__!g;
-        if ($args{wrapper}) {
-            *{"Perinci::Sub::Wrapper::handlemeta_$n"} =
-                sub { $args{wrapper}{meta} };
-            *{"Perinci::Sub::Wrapper::handle_$n"} =
-                $args{wrapper}{handler};
-        } else {
-            *{"Perinci::Sub::Wrapper::handlemeta_$n"} =
-                sub { {} };
-        }
+        *{"Perinci::Sub::Wrapper::handlemeta_$n"} =
+            sub { $args{wrapper}{meta} };
+        *{"Perinci::Sub::Wrapper::handle_$n"} =
+            $args{wrapper}{handler};
+    }
+
+    # install Perinci::CmdLine help handler
+    if ($args{cmdline_help} && $INC{"Perinci/CmdLine.pm"}) {
+        no strict 'refs';
+        my $n = $name; $n =~ s!/!__!g;
+        *{"Perinci::CmdLine::help_hookmeta_$n"} =
+            sub { $args{cmdline_help}{meta} };
+        *{"Perinci::CmdLine::help_hook_$n"} =
+            $args{cmdline_help}{handler};
+    }
+
+    # install Perinci::Sub::To::POD help hook
+    if ($args{pod} && $INC{"Perinci/Sub/To/POD.pm"}) {
+        no strict 'refs';
+        my $n = $name; $n =~ s!/!__!g;
+        *{"Perinci::Sub::To::POD::hookmeta_$n"} =
+            sub { $args{pod}{meta} };
+        *{"Perinci::Sub::To::POD::hook_$n"} =
+            $args{pod}{handler};
     }
 }
 
@@ -86,7 +100,7 @@ Perinci::Sub::PropertyUtil - Utility routines for Perinci::Sub::Property::* modu
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 SYNOPSIS
 
